@@ -10,7 +10,7 @@ import os
 import sys
 from traceback import extract_tb
 from types import TracebackType
-from typing import Any, Callable, Optional
+from typing import Any, Callable, List, Optional, Tuple
 
 import color
 from color import format_color, use_color
@@ -23,22 +23,23 @@ def pyleet() -> int:
         print_error('No filename provided')
         return 1
 
-    filename = sys.argv[1]
-    return run_leetcode_solution(filename)
+    filepath = sys.argv[1]
+    return run_leetcode_solution(filepath)
 
 
-def run_leetcode_solution(filename: str) -> int:
+def run_leetcode_solution(filepath: str) -> int:
     """Runs the leetcode solution file"""
     try:
-        sys.path.append('.')
-        module_name = filename.removesuffix('.py')
+        sys.path.append('.')  # TODO: add support for subdirectories
+        filename = os.path.basename(filepath)
+        module_name = filename[:-3] if filename.endswith('.py') else filename
         module = __import__(module_name)
     except ModuleNotFoundError:
-        print_error(f'Unable to import file: {filename}')
+        print_error(f'Unable to import file: {filepath}')
         return 1
 
     if not hasattr(module, 'Solution'):
-        print_error(f'No Solution class found in file: {filename}')
+        print_error(f'No Solution class found in file: {filepath}')
         return 1
 
     solution_class = getattr(module, 'Solution')
@@ -57,7 +58,7 @@ def run_leetcode_solution(filename: str) -> int:
     method = getattr(solution_class(), method_name)
 
     if not hasattr(module, 'tests'):
-        print_error(f'No tests found in file: {filename}')
+        print_error(f'No tests found in file: {filepath}')
         return 1
 
     tests = getattr(module, 'tests')
@@ -80,8 +81,8 @@ def run_leetcode_solution(filename: str) -> int:
 
 def default_validator(
         method: Callable[..., Any],
-        inputs: tuple[Any, ...],
-        expected: tuple[Any, ...]) -> None:
+        inputs: Tuple[Any, ...],
+        expected: Tuple[Any, ...]) -> None:
     """Default validator for leetcode tests"""
     output = method(*inputs)
     assert output == expected, (output, expected)
@@ -89,17 +90,21 @@ def default_validator(
 
 def run_testcases(
     method:  Callable[..., Any],
-    tests: list[tuple[Any, Any]],
+    tests: List[Tuple[Any, Any]],
     validator: Any,
-) -> list[tuple[TracebackType, Any, Any, Any]]:
+) -> List[Tuple[TracebackType, Any, Any, Any]]:
     """Run given test cases, and collect all failing assertions"""
-    failed_testcases: list[tuple[TracebackType, Any, Any, Any]] = []
+    failed_testcases: List[Tuple[TracebackType, Any, Any, Any]] = []
 
     for index, (inputs, expected) in enumerate(tests, start=1):
         try:
             validator(method, inputs, expected)
             result = 'PASSED'
             result_color = color.GREEN + color.BOLD
+
+        except KeyboardInterrupt:
+            break
+
         except AssertionError as exc:
             *_, trace = sys.exc_info()
             assert trace is not None
@@ -122,12 +127,13 @@ def run_testcases(
 
         test_case = f"Test {index} - ({', '.join(map(str, inputs))})"
         print_test_result(test_case, result, result_color)
+    print()
 
     return failed_testcases
 
 
 def print_failed_testcases(
-        failed_testcases: list[tuple[TracebackType, Any, Any, Any]]
+        failed_testcases: List[Tuple[TracebackType, Any, Any, Any]]
 ) -> None:
     """Prints failed test cases"""
     err_color = color.BOLD + color.ERROR
@@ -151,6 +157,10 @@ def print_test_result(test_case: str, result: str, clr: str) -> None:
 
     width, _ = os.get_terminal_size()
     test_case_width = len(test_case)
+    if test_case_width > width - len(result) - 3:
+        test_case_width = width - len(result) - 3
+        test_case = test_case[:test_case_width]
+
     rest_width = width - test_case_width + apparent_padding
 
     print(f'{test_case}{colored_result:.>{rest_width}}')
